#!/bin/bash

export OSSYS=`uname -s`

unset PYTHONHOME
unset PYTHONSTARTUP

export PYPREFIX=/usr/local/CarPy
export PREFIX=${PYPREFIX}/builds
export SRC=${PREFIX}/src

if [ "$OSSYS" = 'Darwin' ] ; then
  export NP=`/usr/sbin/sysctl -n hw.availcpu`
  export ARCHSYS=`uname -s`
  export ARCHMODEL=`uname -m`
  export OSVER=`sw_vers -productVersion | /usr/bin/python -ESc "import sys; print '.'.join(sys.stdin.read().split('.')[:2])"`
  if [ -z "$PYTHONBASE" ] ; then
     export PYTHONBASE=${PREFIX}/${ARCHSYS}.${OSVER}.${ARCHMODEL}
  fi
  if [ ! -d $PYTHONBASE ] ; then
     echo "Error.  Folder $PYTHONBASE does not exist.  You likely don't have"
     echo "the correct binary release.  Try building from source or explicitly"
     echo "set the PYTHONBASE environment variable."
  fi
  export MAKES=${PYTHONBASE}.makes
  #export MACOSX_DEPLOYMENT_TARGET=10.6
  export DYLD_FALLBACK_LIBRARY_PATH=.:${PYTHONBASE}/lib:${PYTHONBASE}/lib/pgplot:${PYTHONBASE}/lib/vtk-5.3
  export LD_LIBRARY_PATH=${DYLD_FALLBACK_LIBRARY_PATH}

  export VERSION=`/usr/bin/python -c 'import sys,os; print os.path.basename(os.path.realpath(os.environ["PYTHONBASE"]+"/Python.framework/Versions/Current"))'`
  export PYTHONFBASE=${PYTHONBASE}/Python.framework/Versions/${VERSION}
  export PYTHONWEXECUTABLE=${PYTHONFBASE}/Resources/Python.app/Contents/MacOS/Python
  export PYTHONLIB=${PYTHONFBASE}/lib/python${VERSION}
  export PYTHONINC=${PYTHONFBASE}/include/python${VERSION}
  export PYTHONSITE=${PYTHONFBASE}/lib/python${VERSION}/site-packages
  export PATH=${PYTHONBASE}/bin:${PYTHONFBASE}/bin:${PYPREFIX}/dist/bin_local:${PYPREFIX}/dist/bin:${PYPREFIX}/dist/bin_oldnumeric:${PATH}
elif [ "$OSSYS" = "Linux" ] ;  then
  export NP=`grep processor /proc/cpuinfo | wc -l`
  export ARCHSYS=`lsb_release -i -s`
  export ARCHMODEL=`arch`
  export OSVER=`lsb_release -r -s`
  export ARCHMHZ=`grep -m 1 'cpu MHz' /proc/cpuinfo | sed -e 's/.*://g' -e 's/ //g'`
  export ARCHBIT=`uname -m | sed -e 's/i686/32/' -e 's/x86_64/64/'`
  if [ -z "$PYTHONBASE" ] ; then
     export PYTHONBASE=${PREFIX}/${ARCHSYS}.${OSVER}.${ARCHMODEL}
  fi
  if [ ! -d $PYTHONBASE ] ; then
     echo "Error.  Folder $PYTHONBASE does not exist.  You likely don't have"
     echo "the correct binary release.  Try building from source or explicitly"
     echo "set the PYTHONBASE environment variable."
     exit
  fi
  export MAKES=${PYTHONBASE}.makes
  export LD_LIBRARY_PATH=${PYTHONBASE}/lib:${PYTHONBASE}/lib/pgplot:${PYTHONBASE}/lib/vtk-5.3

  export VERSION=`${PYTHONBASE}/bin/python -c 'import sys; print "%d.%d" % sys.version_info[:2]'`

  export PYTHONLIB=${PYTHONBASE}/lib/python${VERSION}
  export PYTHONINC=${PYTHONBASE}/include/python${VERSION}
  export PYTHONSITE=${PYTHONBASE}/lib/python${VERSION}/site-packages
  export PATH=${PYTHONBASE}/bin:${PYPREFIX}/dist/bin_local:${PYPREFIX}/dist/bin:${PYPREFIX}/dist/bin_oldnumeric:${PATH}
fi

echo ${PYTHONBASE}

export PGPLOT_DIR=${PYTHONBASE}/lib/pgplot
export PGPLOT_FONT=${PGPLOT_DIR}/grfont.dat
export PGPLOT_DEV=/xs
export PGPLOT_SIZE=8.5

export BUILDS=${PYTHONBASE}/builds

export NUMDIR=${PYTHONSITE}/numpy/core/include/

export PYTHONPATH=.:${PYPREFIX}/dist/lib_local:${PYPREFIX}/dist/lib:${PYPREFIX}/dist/lib_oldnumeric

export PYTHONDATA=${PYPREFIX}/datafiles

